@@ -22,6 +22,7 @@ from botocore.client import BaseClient, ClientMeta
 from .literals import EndpointStateType, JobRunStateType, VirtualClusterStateType
 from .paginator import (
     ListJobRunsPaginator,
+    ListJobTemplatesPaginator,
     ListManagedEndpointsPaginator,
     ListVirtualClustersPaginator,
 )
@@ -29,15 +30,20 @@ from .type_defs import (
     CancelJobRunResponseTypeDef,
     ConfigurationOverridesTypeDef,
     ContainerProviderTypeDef,
+    CreateJobTemplateResponseTypeDef,
     CreateManagedEndpointResponseTypeDef,
     CreateVirtualClusterResponseTypeDef,
+    DeleteJobTemplateResponseTypeDef,
     DeleteManagedEndpointResponseTypeDef,
     DeleteVirtualClusterResponseTypeDef,
     DescribeJobRunResponseTypeDef,
+    DescribeJobTemplateResponseTypeDef,
     DescribeManagedEndpointResponseTypeDef,
     DescribeVirtualClusterResponseTypeDef,
     JobDriverTypeDef,
+    JobTemplateDataTypeDef,
     ListJobRunsResponseTypeDef,
+    ListJobTemplatesResponseTypeDef,
     ListManagedEndpointsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     ListVirtualClustersResponseTypeDef,
@@ -109,6 +115,22 @@ class EMRContainersClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#close)
         """
 
+    def create_job_template(
+        self,
+        *,
+        name: str,
+        clientToken: str,
+        jobTemplateData: JobTemplateDataTypeDef,
+        tags: Mapping[str, str] = ...,
+        kmsKeyArn: str = ...
+    ) -> CreateJobTemplateResponseTypeDef:
+        """
+        Creates a job template.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Client.create_job_template)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#create_job_template)
+        """
+
     def create_managed_endpoint(
         self,
         *,
@@ -144,6 +166,14 @@ class EMRContainersClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#create_virtual_cluster)
         """
 
+    def delete_job_template(self, *, id: str) -> DeleteJobTemplateResponseTypeDef:
+        """
+        Deletes a job template.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Client.delete_job_template)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#delete_job_template)
+        """
+
     def delete_managed_endpoint(
         self, *, id: str, virtualClusterId: str
     ) -> DeleteManagedEndpointResponseTypeDef:
@@ -170,6 +200,14 @@ class EMRContainersClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#describe_job_run)
         """
 
+    def describe_job_template(self, *, id: str) -> DescribeJobTemplateResponseTypeDef:
+        """
+        Displays detailed information about a specified job template.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Client.describe_job_template)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#describe_job_template)
+        """
+
     def describe_managed_endpoint(
         self, *, id: str, virtualClusterId: str
     ) -> DescribeManagedEndpointResponseTypeDef:
@@ -220,6 +258,21 @@ class EMRContainersClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#list_job_runs)
         """
 
+    def list_job_templates(
+        self,
+        *,
+        createdAfter: Union[datetime, str] = ...,
+        createdBefore: Union[datetime, str] = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
+    ) -> ListJobTemplatesResponseTypeDef:
+        """
+        Lists job templates based on a set of parameters.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Client.list_job_templates)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#list_job_templates)
+        """
+
     def list_managed_endpoints(
         self,
         *,
@@ -269,12 +322,14 @@ class EMRContainersClient(BaseClient):
         *,
         virtualClusterId: str,
         clientToken: str,
-        executionRoleArn: str,
-        releaseLabel: str,
-        jobDriver: JobDriverTypeDef,
         name: str = ...,
+        executionRoleArn: str = ...,
+        releaseLabel: str = ...,
+        jobDriver: JobDriverTypeDef = ...,
         configurationOverrides: ConfigurationOverridesTypeDef = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        jobTemplateId: str = ...,
+        jobTemplateParameters: Mapping[str, str] = ...
     ) -> StartJobRunResponseTypeDef:
         """
         Starts a job run.
@@ -306,6 +361,15 @@ class EMRContainersClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_job_templates"]
+    ) -> ListJobTemplatesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_managed_endpoints"]
