@@ -25,9 +25,11 @@ __all__ = (
     "FailureReasonType",
     "JobRunStateType",
     "ListJobRunsPaginatorName",
+    "ListJobTemplatesPaginatorName",
     "ListManagedEndpointsPaginatorName",
     "ListVirtualClustersPaginatorName",
     "PersistentAppUIType",
+    "TemplateParameterDataTypeType",
     "VirtualClusterStateType",
     "EMRContainersServiceName",
     "ServiceName",
@@ -48,9 +50,11 @@ JobRunStateType = Literal[
     "CANCELLED", "CANCEL_PENDING", "COMPLETED", "FAILED", "PENDING", "RUNNING", "SUBMITTED"
 ]
 ListJobRunsPaginatorName = Literal["list_job_runs"]
+ListJobTemplatesPaginatorName = Literal["list_job_templates"]
 ListManagedEndpointsPaginatorName = Literal["list_managed_endpoints"]
 ListVirtualClustersPaginatorName = Literal["list_virtual_clusters"]
 PersistentAppUIType = Literal["DISABLED", "ENABLED"]
+TemplateParameterDataTypeType = Literal["NUMBER", "STRING"]
 VirtualClusterStateType = Literal["ARRESTED", "RUNNING", "TERMINATED", "TERMINATING"]
 EMRContainersServiceName = Literal["emr-containers"]
 ServiceName = Literal[
@@ -385,7 +389,9 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
-PaginatorName = Literal["list_job_runs", "list_managed_endpoints", "list_virtual_clusters"]
+PaginatorName = Literal[
+    "list_job_runs", "list_job_templates", "list_managed_endpoints", "list_virtual_clusters"
+]
 RegionName = Literal[
     "ap-northeast-1",
     "ap-northeast-2",
