@@ -20,6 +20,7 @@ from .literals import (
     FailureReasonType,
     JobRunStateType,
     PersistentAppUIType,
+    TemplateParameterDataTypeType,
     VirtualClusterStateType,
 )
 
@@ -40,24 +41,32 @@ __all__ = (
     "CloudWatchMonitoringConfigurationTypeDef",
     "ConfigurationTypeDef",
     "EksInfoTypeDef",
+    "DeleteJobTemplateRequestRequestTypeDef",
     "DeleteManagedEndpointRequestRequestTypeDef",
     "DeleteVirtualClusterRequestRequestTypeDef",
     "DescribeJobRunRequestRequestTypeDef",
+    "DescribeJobTemplateRequestRequestTypeDef",
     "DescribeManagedEndpointRequestRequestTypeDef",
     "DescribeVirtualClusterRequestRequestTypeDef",
     "SparkSqlJobDriverTypeDef",
     "SparkSubmitJobDriverTypeDef",
+    "TemplateParameterConfigurationTypeDef",
     "PaginatorConfigTypeDef",
     "ListJobRunsRequestRequestTypeDef",
+    "ListJobTemplatesRequestRequestTypeDef",
     "ListManagedEndpointsRequestRequestTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListVirtualClustersRequestRequestTypeDef",
     "S3MonitoringConfigurationTypeDef",
+    "ParametricCloudWatchMonitoringConfigurationTypeDef",
+    "ParametricS3MonitoringConfigurationTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "CancelJobRunResponseTypeDef",
+    "CreateJobTemplateResponseTypeDef",
     "CreateManagedEndpointResponseTypeDef",
     "CreateVirtualClusterResponseTypeDef",
+    "DeleteJobTemplateResponseTypeDef",
     "DeleteManagedEndpointResponseTypeDef",
     "DeleteVirtualClusterResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
@@ -65,23 +74,31 @@ __all__ = (
     "ContainerInfoTypeDef",
     "JobDriverTypeDef",
     "ListJobRunsRequestListJobRunsPaginateTypeDef",
+    "ListJobTemplatesRequestListJobTemplatesPaginateTypeDef",
     "ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
     "ListVirtualClustersRequestListVirtualClustersPaginateTypeDef",
     "MonitoringConfigurationTypeDef",
+    "ParametricMonitoringConfigurationTypeDef",
     "ContainerProviderTypeDef",
     "ConfigurationOverridesTypeDef",
+    "ParametricConfigurationOverridesTypeDef",
     "CreateVirtualClusterRequestRequestTypeDef",
     "VirtualClusterTypeDef",
     "CreateManagedEndpointRequestRequestTypeDef",
     "EndpointTypeDef",
     "JobRunTypeDef",
     "StartJobRunRequestRequestTypeDef",
+    "JobTemplateDataTypeDef",
     "DescribeVirtualClusterResponseTypeDef",
     "ListVirtualClustersResponseTypeDef",
     "DescribeManagedEndpointResponseTypeDef",
     "ListManagedEndpointsResponseTypeDef",
     "DescribeJobRunResponseTypeDef",
     "ListJobRunsResponseTypeDef",
+    "CreateJobTemplateRequestRequestTypeDef",
+    "JobTemplateTypeDef",
+    "DescribeJobTemplateResponseTypeDef",
+    "ListJobTemplatesResponseTypeDef",
 )
 
 CancelJobRunRequestRequestTypeDef = TypedDict(
@@ -162,6 +179,13 @@ EksInfoTypeDef = TypedDict(
     total=False,
 )
 
+DeleteJobTemplateRequestRequestTypeDef = TypedDict(
+    "DeleteJobTemplateRequestRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
 DeleteManagedEndpointRequestRequestTypeDef = TypedDict(
     "DeleteManagedEndpointRequestRequestTypeDef",
     {
@@ -185,6 +209,13 @@ DescribeJobRunRequestRequestTypeDef = TypedDict(
     },
 )
 
+DescribeJobTemplateRequestRequestTypeDef = TypedDict(
+    "DescribeJobTemplateRequestRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
 DescribeManagedEndpointRequestRequestTypeDef = TypedDict(
     "DescribeManagedEndpointRequestRequestTypeDef",
     {
@@ -218,7 +249,7 @@ _RequiredSparkSubmitJobDriverTypeDef = TypedDict(
 _OptionalSparkSubmitJobDriverTypeDef = TypedDict(
     "_OptionalSparkSubmitJobDriverTypeDef",
     {
-        "entryPointArguments": List[str],
+        "entryPointArguments": Sequence[str],
         "sparkSubmitParameters": str,
     },
     total=False,
@@ -231,6 +262,15 @@ class SparkSubmitJobDriverTypeDef(
     pass
 
 
+TemplateParameterConfigurationTypeDef = TypedDict(
+    "TemplateParameterConfigurationTypeDef",
+    {
+        "type": TemplateParameterDataTypeType,
+        "defaultValue": str,
+    },
+    total=False,
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -267,6 +307,17 @@ class ListJobRunsRequestRequestTypeDef(
     pass
 
 
+ListJobTemplatesRequestRequestTypeDef = TypedDict(
+    "ListJobTemplatesRequestRequestTypeDef",
+    {
+        "createdAfter": Union[datetime, str],
+        "createdBefore": Union[datetime, str],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
 _RequiredListManagedEndpointsRequestRequestTypeDef = TypedDict(
     "_RequiredListManagedEndpointsRequestRequestTypeDef",
     {
@@ -322,6 +373,23 @@ S3MonitoringConfigurationTypeDef = TypedDict(
     },
 )
 
+ParametricCloudWatchMonitoringConfigurationTypeDef = TypedDict(
+    "ParametricCloudWatchMonitoringConfigurationTypeDef",
+    {
+        "logGroupName": str,
+        "logStreamNamePrefix": str,
+    },
+    total=False,
+)
+
+ParametricS3MonitoringConfigurationTypeDef = TypedDict(
+    "ParametricS3MonitoringConfigurationTypeDef",
+    {
+        "logUri": str,
+    },
+    total=False,
+)
+
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -347,6 +415,17 @@ CancelJobRunResponseTypeDef = TypedDict(
     },
 )
 
+CreateJobTemplateResponseTypeDef = TypedDict(
+    "CreateJobTemplateResponseTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "arn": str,
+        "createdAt": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 CreateManagedEndpointResponseTypeDef = TypedDict(
     "CreateManagedEndpointResponseTypeDef",
     {
@@ -368,6 +447,14 @@ CreateVirtualClusterResponseTypeDef = TypedDict(
     },
 )
 
+DeleteJobTemplateResponseTypeDef = TypedDict(
+    "DeleteJobTemplateResponseTypeDef",
+    {
+        "id": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 DeleteManagedEndpointResponseTypeDef = TypedDict(
     "DeleteManagedEndpointResponseTypeDef",
     {
@@ -447,6 +534,16 @@ class ListJobRunsRequestListJobRunsPaginateTypeDef(
     pass
 
 
+ListJobTemplatesRequestListJobTemplatesPaginateTypeDef = TypedDict(
+    "ListJobTemplatesRequestListJobTemplatesPaginateTypeDef",
+    {
+        "createdAfter": Union[datetime, str],
+        "createdBefore": Union[datetime, str],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
 _RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
     "_RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
     {
@@ -496,6 +593,16 @@ MonitoringConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+ParametricMonitoringConfigurationTypeDef = TypedDict(
+    "ParametricMonitoringConfigurationTypeDef",
+    {
+        "persistentAppUI": str,
+        "cloudWatchMonitoringConfiguration": ParametricCloudWatchMonitoringConfigurationTypeDef,
+        "s3MonitoringConfiguration": ParametricS3MonitoringConfigurationTypeDef,
+    },
+    total=False,
+)
+
 _RequiredContainerProviderTypeDef = TypedDict(
     "_RequiredContainerProviderTypeDef",
     {
@@ -527,6 +634,15 @@ ConfigurationOverridesTypeDef = TypedDict(
     total=False,
 )
 
+ParametricConfigurationOverridesTypeDef = TypedDict(
+    "ParametricConfigurationOverridesTypeDef",
+    {
+        "applicationConfiguration": Sequence["ConfigurationTypeDef"],
+        "monitoringConfiguration": ParametricMonitoringConfigurationTypeDef,
+    },
+    total=False,
+)
+
 _RequiredCreateVirtualClusterRequestRequestTypeDef = TypedDict(
     "_RequiredCreateVirtualClusterRequestRequestTypeDef",
     {
@@ -647,17 +763,19 @@ _RequiredStartJobRunRequestRequestTypeDef = TypedDict(
     {
         "virtualClusterId": str,
         "clientToken": str,
-        "executionRoleArn": str,
-        "releaseLabel": str,
-        "jobDriver": JobDriverTypeDef,
     },
 )
 _OptionalStartJobRunRequestRequestTypeDef = TypedDict(
     "_OptionalStartJobRunRequestRequestTypeDef",
     {
         "name": str,
+        "executionRoleArn": str,
+        "releaseLabel": str,
+        "jobDriver": JobDriverTypeDef,
         "configurationOverrides": ConfigurationOverridesTypeDef,
         "tags": Mapping[str, str],
+        "jobTemplateId": str,
+        "jobTemplateParameters": Mapping[str, str],
     },
     total=False,
 )
@@ -669,6 +787,29 @@ class StartJobRunRequestRequestTypeDef(
     pass
 
 
+_RequiredJobTemplateDataTypeDef = TypedDict(
+    "_RequiredJobTemplateDataTypeDef",
+    {
+        "executionRoleArn": str,
+        "releaseLabel": str,
+        "jobDriver": JobDriverTypeDef,
+    },
+)
+_OptionalJobTemplateDataTypeDef = TypedDict(
+    "_OptionalJobTemplateDataTypeDef",
+    {
+        "configurationOverrides": ParametricConfigurationOverridesTypeDef,
+        "parameterConfiguration": Mapping[str, TemplateParameterConfigurationTypeDef],
+        "jobTags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class JobTemplateDataTypeDef(_RequiredJobTemplateDataTypeDef, _OptionalJobTemplateDataTypeDef):
+    pass
+
+
 DescribeVirtualClusterResponseTypeDef = TypedDict(
     "DescribeVirtualClusterResponseTypeDef",
     {
@@ -719,3 +860,70 @@ ListJobRunsResponseTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+_RequiredCreateJobTemplateRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateJobTemplateRequestRequestTypeDef",
+    {
+        "name": str,
+        "clientToken": str,
+        "jobTemplateData": JobTemplateDataTypeDef,
+    },
+)
+_OptionalCreateJobTemplateRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateJobTemplateRequestRequestTypeDef",
+    {
+        "tags": Mapping[str, str],
+        "kmsKeyArn": str,
+    },
+    total=False,
+)
+
+
+class CreateJobTemplateRequestRequestTypeDef(
+    _RequiredCreateJobTemplateRequestRequestTypeDef, _OptionalCreateJobTemplateRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredJobTemplateTypeDef = TypedDict(
+    "_RequiredJobTemplateTypeDef",
+    {
+        "jobTemplateData": JobTemplateDataTypeDef,
+    },
+)
+_OptionalJobTemplateTypeDef = TypedDict(
+    "_OptionalJobTemplateTypeDef",
+    {
+        "name": str,
+        "id": str,
+        "arn": str,
+        "createdAt": datetime,
+        "createdBy": str,
+        "tags": Dict[str, str],
+        "kmsKeyArn": str,
+        "decryptionError": str,
+    },
+    total=False,
+)
+
+
+class JobTemplateTypeDef(_RequiredJobTemplateTypeDef, _OptionalJobTemplateTypeDef):
+    pass
+
+
+DescribeJobTemplateResponseTypeDef = TypedDict(
+    "DescribeJobTemplateResponseTypeDef",
+    {
+        "jobTemplate": JobTemplateTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListJobTemplatesResponseTypeDef = TypedDict(
+    "ListJobTemplatesResponseTypeDef",
+    {
+        "templates": List[JobTemplateTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
